*! version 1.1.0  30jul2008
program svy_xmpl
	version 11

	gettoken log : 0
	if `"`log'"' == "log" {
		gettoken log 0 : 0
	}
	local sub : word 1 of `0'
	if substr(`"`sub'"',1,2) != "Ex" {
		di as err `"`sub': subroutine not recognized"'
		exit 199
	}
	set more off
	global JSP_nomore
	if "`log'" == "log" {
		global JSP_nomore on
		local logfile = lower("`sub'")
		quietly log using `logfile'.smcl, replace
	}
	capture noisily `0'
	if "`log'" == "log" {
		quietly log close
		log texman `logfile'.smcl ../tex/logs/`logfile'.log.tex, replace
		rm `logfile'.smcl
	}
	global JSP_nomore
	if c(rc) {
		di as err `"problem with subroutine `sub'"'
		exit c(rc)
	}
end

// subroutines **************************************************************

program Echo
	display as input `"{p 0 4 2}`0'{p_end}"'
end

program BreakExec
	di
	Echo . `0'
	local cmd : subinstr local 0 "{break}" "", all
	`cmd'
end

program Exec
	di
	Echo . `0'
	`0'
end

program ExecNoBlank
	Echo . `0'
	`0'
end

program WebUseData
	syntax anything(name=fn id="filename") [, mem(string) ]
	drop _all
	if `"`mem'"' != "" {
		clear all
		quietly set mem `mem'
	}
	if !strpos(`"`fn'"',".") {
		local ext .dta
	}
	Echo . webuse `fn'
	capture findfile `fn'`ext'
	if !c(rc) {
		use `fn'
	}
	else {
		webuse `fn'
		quietly save `fn'
	}
end

program SysUseData
	syntax anything(name=fn id="filename") [, mem(string) ]
	drop _all
	if `"`mem'"' != "" {
		clear all
		quietly set mem `mem'
	}
	if !strpos(`"`fn'"',".") {
		local ext .dta
	}
	ExecNoBlank sysuse `fn'
end

program More
	if ("$JSP_nomore" != "") exit
	set more on
	more
end

// examples *****************************************************************

program ExSvyProp
	Echo *** Second National Health and Nutrition Examination Survey
	di
	WebUseData nhanes2, mem(5m)
	Exec proportion sex
	More
	Exec svy: proportion sex
end

program ExSvyset1
	Echo *** The auto data that ships with Stata
	SysUseData auto
	Exec svyset _n
	More
	di
	Echo *** National Maternal and Infant Health Survey
	di
	WebUseData nmihs
	Exec svyset [pw=finwgt], strata(stratan)
	More
	di
	Echo *** Simulated data
	WebUseData fpc
	Exec svyset psuid [pw=weight], strata(stratid) fpc(Nh)
end

program ExSvyset2
	WebUseData seniors
	local cmd "svyset county [pw=sampwgt], strata(state) fpc(ncounties)"
	local cmd "`cmd'{break}|| school, fpc(nschools)"
	local cmd "`cmd'{break}|| _n, strata(gender) fpc(nseniors)"
	BreakExec `cmd'
end

program ExPoststrata1a
	Echo *** Cat and dog data from Levy and Lemeshow (1999)
	di
	WebUseData poststrata
	Exec bysort type: sum totexp
end

program ExPoststrata1b
	Exec svyset [pw=weight], poststrata(type) postweight(postwgt) fpc(fpc)
	Exec svy: mean totexp
end

program ExPoststrata1c
	Exec svyset _n [pw=weight]
	Exec svy: mean totexp
end

program ExSvydes1a
	Echo *** Second National Health and Nutrition Examination Survey
	di
	WebUseData nhanes2
	Exec svydes
end

program ExSvydes1b
	Echo *** Mean high density lipids (mg/dL)
	Exec svy: mean hdresult
end

program ExSvydes1c
	Echo *** Restrict to the estimation sample
	Exec svydes if e(sample), single
end

program ExSvydes1d
	Echo *** Specifying variables for more information
	Exec svydes hdresult, single
end

program ExSvyTotal
	WebUseData seniors
	Exec svyset
	di
	Echo *** Estimate number of seniors who have smoked
	Exec svy: total smoked
	More
	di
	Echo *** Use first stage without FPC
	Exec svyset county [pw=sampwgt], strata(state)
	Exec svy: total smoked
end

program ExSvyLogit
	Echo *** Second National Health and Nutrition Examination Survey
	di
	WebUseData nhanes2
	Exec svyset
	More
	di
	Echo *** Model high blood pressure on some demographics
	Exec describe highbp height weight age female
	di
	More
	Exec svy: logit highbp height weight age female
end

program ExSvyBrrLogit
	* should have the same resulting coefficients as above example
	Echo *** Second National Health and Nutrition Examination Survey
	di
	WebUseData nhanes2brr
	Exec svyset [pw=finalwgt], vce(brr) mse brrweight(brr_*)
	More
	Exec svy: logit highbp height weight age female
end

program ExSvyJkLogit1
	Echo *** Second National Health and Nutrition Examination Survey
	di
	WebUseData nhanes2
	Exec svyset
	More
	Exec svy jknife, mse: logit highbp height weight age female
end

program ExSvyJkLogit2a
	Echo *** Second National Health and Nutrition Examination Survey
	di
	WebUseData nhanes2jknife
	di
	Echo . svyset [pw=finalwgt], vce(jackknife) jkrweight(jkw_*)
	svyset
	Exec char list jkw_1[]
end

program ExSvyJkLogit2b
	Exec svy, mse: logit highbp height weight age female
end

program ExSubpop
	Echo *** National Maternal and Infant Health Survey
	di
	WebUseData nmihs
	Exec svyset [pw=finwgt], strata(stratan)
	di
	Echo *** Focus:  birthweight, mothers with high blood pressure
	Exec describe birthwgt highbp
	Exec label list hibp
	More
	di
	Echo *** Subpopulation estimation
	Exec svy, subpop(highbp): mean birthwgt
	More
	di
	Echo *** Restricted sample estimation
	Exec svy: mean birthwgt if highbp
end

program ExEffects1
	Echo *** National Maternal and Infant Health Survey
	di
	WebUseData nmihs
	Exec svyset [pw=finwgt], strata(stratan)
	di
	Echo *** Focus:  birthweight between mothers ///
		with normal and high blood pressure
	Exec describe birthwgt highbp
	di
	Echo *** Labels that can also be used as Stata names
	Exec label list hibp
	Exec label define bloodpressure 0 "BPnormal" 1 "BPhigh"
	Exec label values highbp bloodpressure
end

program ExEffects2
	Echo *** Focus:  birthweight between mothers ///
		with normal and high blood pressure
	Exec svy: mean birthwgt, over(highbp)
end

program ExEffects3
	Echo *** Design effects
	Exec estat effects
end

program ExEffects4
	Echo *** Misspecification effects require an extra model fit
	Exec estat effects, meff meft
end

program ExEffects5
	Echo *** Focus:  birthweight between normal and high blood pressure
	di
	Echo *** Linear combinations
	Exec lincom [birthwgt]BPnormal - [birthwgt]BPhigh
	More
	di
	Echo *** Effects for linear combinations
	Exec estat lceffects [birthwgt]BPnormal - [birthwgt]BPhigh
end

exit
